@@ -1,20 +1,21 @@
 package Time::Duration::Parse;
-$Time::Duration::Parse::VERSION = '0.10';
+$Time::Duration::Parse::VERSION = '0.16';
+use 5.006;
 use strict;
 use warnings;
 
 use Carp;
-use Exporter::Lite;
+use Exporter 5.57 qw(import);
 our @EXPORT = qw( parse_duration );
 
 # This map is taken from Cache and Cache::Cache
 # map of expiration formats to their respective time in seconds
 my %Units = ( map(($_,             1), qw(s second seconds sec secs)),
               map(($_,            60), qw(m minute minutes min mins)),
-              map(($_,         60*60), qw(h hr hour hours)),
+              map(($_,         60*60), qw(h hr hrs hour hours)),
               map(($_,      60*60*24), qw(d day days)),
               map(($_,    60*60*24*7), qw(w week weeks)),
-              map(($_,   60*60*24*30), qw(M month months)),
+              map(($_,   60*60*24*30), qw(M month months mo mon mons)),
               map(($_,  60*60*24*365), qw(y year years)) );
 
 sub parse_duration {
@@ -29,7 +30,7 @@ sub parse_duration {
     }
 
     # Convert hh:mm(:ss)? to something we understand
-    $timespec =~ s/\b(\d+):(\d\d):(\d\d)\b/$1h $2m $3s/g;
+    $timespec =~ s/\b(\d+):(\d\d):(\d\d(\.\d+)?)\b/$1h $2m $3s/g;
     $timespec =~ s/\b(\d+):(\d\d)\b/$1h $2m/g;
 
     my $duration = 0;
@@ -70,8 +71,10 @@ Time::Duration::Parse - Parse string that represents time duration
 Time::Duration::Parse is a module to parse human readable duration
 strings like I<2 minutes and 3 seconds> to seconds.
 
-It does the opposite of I<duration_exact> function in Time::Duration
-and is roundtrip safe. So, the following is always true.
+It does the opposite of L<Time::Duration/duration_exact> function
+in L<Time::Duration>
+and is roundtrip safe.
+So, the following is always true.
 
   use Time::Duration::Parse;
   use Time::Duration;
@@ -87,9 +90,10 @@ and is roundtrip safe. So, the following is always true.
 
   $seconds = parse_duration($string);
 
-Parses duration string and returns seconds. When it encounters an
-error in a given string, it dies an exception saying "Unknown
-timespec: blah blah blah". This function is exported by default.
+Parses duration string and returns seconds.
+When it encounters an error in a given string,
+it dies with an exception saying "Unknown timespec: blah blah blah".
+This function is exported by default.
 
 =back
 
@@ -108,13 +112,13 @@ L<Time::Duration::LocaleObject> provides an OO interface to the
 C<Time::Duration::??> modules, which provide language-specific versions
 of L<Time::Duration>.
 
-L<Date::Manip>,
-L<DateTime::Format::Duration>,
-L<http://use.perl.org/~miyagawa/journal/30310>
+L<DateTime::Format::Duration> can be used to parse natural language
+descriptions of durations, returning an instance of L<DateTime::Duration>,
+which can then be converted to seconds using the C<in_units()> method.
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/Time-Duration-Parse>
+L<https://github.com/neilb/Time-Duration-Parse>
 
 =head1 AUTHOR
 
